from gpaw import GPAW, Mixer, PoissonSolver
from gpaw.mpi import world
from ase.build import bulk
import os

images = []
atoms = bulk('Ti', orthorhombic=True)
kpts = [(8, 4, 4),
        (4, 4, 4),
        (4, 2, 4),
        (4, 2, 2),
        (2, 2, 2),
        (2, 1, 2),
        (2, 1, 1)]

for n in range(7):
    atoms2 = atoms.copy()
    atoms2.rattle(stdev=0.05)
    fname = 'gpaw.{}.txt'.format(n)
    if not os.path.exists(fname):
        world.barrier()
        calc = GPAW(mode='lcao',
                    basis='dzp',
                    parallel=dict(sl_auto=1,
                                  augment_grids=True),
                    poissonsolver=PoissonSolver(relax='GS'),
                    xc='oldLDA',
                    kpts=kpts[n],
                    nbands='120%',
                    txt=fname,
                    mixer=Mixer(0.3, 7, 20.0))
        atoms2.calc = calc
        atoms2.get_potential_energy()
        atoms2.calc = None
        calc = None

    rep = [1, 1, 1]
    c = n % 3
    rep[c] = 2
    images.append(atoms)
    atoms = atoms.repeat(rep)
